summaryrefslogtreecommitdiff
path: root/serial.c
diff options
context:
space:
mode:
authorEric S. Raymond <esr@thyrsus.com>2011-01-11 13:54:57 -0500
committerEric S. Raymond <esr@thyrsus.com>2011-01-11 13:54:57 -0500
commit6c4029a0676b15186a1da0d62695eb1dcb0a3383 (patch)
treeaa245bfea8e5ba246c201e391064f71bbae0f59b /serial.c
parentf844626b0ab579e15b42c565e16c52b0e5b2dd04 (diff)
parentd90cc50f1ca50605dfdce88136135a307a1ceb3f (diff)
downloadgpsd-6c4029a0676b15186a1da0d62695eb1dcb0a3383.tar.gz
It really needs to be %04x in JSON escaping, otherwise we don't get fixed width.
Diffstat (limited to 'serial.c')
-rw-r--r--serial.c11
1 files changed, 7 insertions, 4 deletions
diff --git a/serial.c b/serial.c
index 77b3fd5d..743c0283 100644
--- a/serial.c
+++ b/serial.c
@@ -312,11 +312,14 @@ void gpsd_set_speed(struct gps_device_t *session,
/*
* The device might need a wakeup string before it will send data.
* If we don't know the device type, ship it every driver's wakeup
* in hopes it will respond. But not to USB, because shipping
* probe strings to unknown USB serial adaptors may spam devices
* that aren't GPSes at all and could become confused.
*/
- if (!session->context->readonly && session->sourcetype != source_usb) {
+ if (!session->context->readonly
+ && session->sourcetype != source_usb
+ && session->sourcetype != source_bluetooth) {
if (isatty(session->gpsdata.gps_fd) != 0
&& !session->context->readonly) {
const struct gps_type_t **dp;
@@ -312,11 +312,14 @@ void gpsd_set_speed(struct gps_device_t *session,
* The device might need a wakeup string before it will send data.
* If we don't know the device type, ship it every driver's wakeup
- * in hopes it will respond. But not to USB, because shipping
- * probe strings to unknown USB serial adaptors may spam devices
- * that aren't GPSes at all and could become confused.
+ * in hopes it will respond. But not to USB or Bluetooth, because
+ * shipping probe strings to unknown USB serial adaptors or
+ * Bluetooth devices may spam devices that aren't GPSes at all and
+ * could become confused.
*/